@@ -10,7 +10,7 @@ def wrap(socketio):
     @socketio.on('disconnect')
     def socket_disconnect_handler():
         for room in rooms():
-            socketio.emit('peer-disconnection', {'sid': flask.request.sid}, room=data['room'], include_self=False)
+            socketio.emit('peer-disconnection', {'sid': flask.request.sid}, room=room, include_self=False)
 
     @socketio.on('join')
     def socket_join_room_handler(data):
